@@ -2,8 +2,8 @@
 != netCDF եΥץ󥯥
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: an_file.f90,v 1.3 2006/01/23 01:18:22 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070729 $
+! Version::   $Id: an_file.f90,v 1.4 2007/08/24 07:21:19 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070824 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -137,6 +137,7 @@ contains
     character(len = STRING):: cause_c
     character(*), parameter:: subname = "ANFileOpen"
   continue
+    fileid = -1
     !
     ! ץβ
     !
@@ -214,6 +215,7 @@ contains
         mystat = nf_create(real_filename, mode, memop%id)
         if (mystat /= NF_NOERR) then
           cause_c=filename
+          if (present(stat)) stat = mystat
           goto 999
         end if
       endif
@@ -228,6 +230,7 @@ contains
         ! ̵פȥ顼Ǥƽλ
         if (mystat /= NF_NOERR) then
           cause_c=filename
+          if (present(stat)) stat = mystat
           goto 999
         end if
       else
@@ -237,6 +240,7 @@ contains
         mystat = nf_create(real_filename, mode, memop%id)
         if (mystat /= NF_NOERR) then
           cause_c=filename
+          if (present(stat)) stat = mystat
           goto 999
         end if
       endif
