@@ -2,8 +2,8 @@
 !==  (abstruct) netCDF 󥿡ե
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: an_generic.f90,v 1.3 2006/10/09 10:35:42 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070729 $
+! Version::   $Id: an_generic.f90,v 1.4 2007/08/22 18:34:25 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070824 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -259,12 +259,13 @@ module an_generic
     end subroutine AnAttrGetReal
 
     subroutine AnAttrGetDouble(var, name, value, stat, default)
+      use dc_types, only: DP
       use an_types, only: AN_VARIABLE
       type(AN_VARIABLE), intent(in):: var
       character(len = *), intent(in):: name
-      double precision, intent(out):: value(:)
+      real(DP), intent(out):: value(:)
       integer, intent(out):: stat
-      double precision, intent(in), optional:: default
+      real(DP), intent(in), optional:: default
     end subroutine AnAttrGetDouble
 
     subroutine AnAttrGetInt(var, name, value, stat, default)
@@ -283,7 +284,7 @@ module an_generic
   !  1 ʸʸȤƳǼ졢 T,
   !  F Ȥʤ롣
 
-  interface put_attr
+  interface Put_Attr
 
     subroutine ANVarPutAttrReal(var, name, value, err)
       use an_types, only: AN_VARIABLE
@@ -294,10 +295,11 @@ module an_generic
     end subroutine ANVarPutAttrReal
 
     subroutine ANVarPutAttrDouble(var, name, value, err)
+      use dc_types, only: DP
       use an_types, only: AN_VARIABLE
       type(AN_VARIABLE), intent(in):: var
       character(len = *), intent(in):: name
-      double precision, intent(in):: value(:)
+      real(DP), intent(in):: value(:)
       logical, intent(out), optional:: err
     end subroutine ANVarPutAttrDouble
 
@@ -351,9 +353,9 @@ module an_generic
   ! 
   !
 
-  interface get
+  interface Get
 
-    subroutine anvargetreal(var, start, count, stride, imap, &
+    subroutine ANVarGetReal(var, start, count, stride, imap, &
       & siz, value, iostat)
       use an_types, only: AN_VARIABLE
       type(AN_VARIABLE), intent(in):: var
@@ -364,10 +366,11 @@ module an_generic
       integer, intent(in):: siz
       real, intent(out):: value(siz)
       integer, intent(out):: iostat
-    end subroutine anvargetreal
+    end subroutine ANVarGetReal
 
-    subroutine anvargetdouble(var, start, count, stride, imap, &
+    subroutine ANVarGetDouble(var, start, count, stride, imap, &
       & siz, value, iostat)
+      use dc_types, only: DP
       use an_types, only: AN_VARIABLE
       type(AN_VARIABLE), intent(in):: var
       integer, intent(in):: start(:)
@@ -375,15 +378,29 @@ module an_generic
       integer, intent(in):: stride(:)
       integer, intent(in):: imap(:)
       integer, intent(in):: siz
-      double precision, intent(out):: value(siz)
+      real(DP), intent(out):: value(siz)
       integer, intent(out):: iostat
-    end subroutine anvargetdouble
+    end subroutine ANVarGetDouble
+
+    subroutine ANVarGetInt(var, start, count, stride, imap, &
+      & siz, value, iostat)
+      use dc_types, only: DP
+      use an_types, only: AN_VARIABLE
+      type(AN_VARIABLE), intent(in):: var
+      integer, intent(in):: start(:)
+      integer, intent(in):: count(:)
+      integer, intent(in):: stride(:)
+      integer, intent(in):: imap(:)
+      integer, intent(in):: siz
+      integer, intent(out):: value(siz)
+      integer, intent(out):: iostat
+    end subroutine ANVarGetInt
 
   end interface
 
-  interface put
+  interface Put
 
-    subroutine anvarputreal(var, start, count, stride, imap, &
+    subroutine ANVarPutReal(var, start, count, stride, imap, &
       & siz, value, iostat)
       use an_types, only: AN_VARIABLE
       type(AN_VARIABLE), intent(in):: var
@@ -394,9 +411,23 @@ module an_generic
       integer, intent(in):: siz
       real, intent(in):: value(siz)
       integer, intent(out):: iostat
-    end subroutine anvarputreal
+    end subroutine ANVarPutReal
 
-    subroutine anvarputdouble(var, start, count, stride, imap, &
+    subroutine ANVarPutDouble(var, start, count, stride, imap, &
+      & siz, value, iostat)
+      use dc_types, only: DP
+      use an_types, only: AN_VARIABLE
+      type(AN_VARIABLE), intent(in):: var
+      integer, intent(in):: start(:)
+      integer, intent(in):: count(:)
+      integer, intent(in):: stride(:)
+      integer, intent(in):: imap(:)
+      integer, intent(in):: siz
+      real(DP), intent(in):: value(siz)
+      integer, intent(out):: iostat
+    end subroutine ANVarPutDouble
+
+    subroutine ANVarPutInt(var, start, count, stride, imap, &
       & siz, value, iostat)
       use an_types, only: AN_VARIABLE
       type(AN_VARIABLE), intent(in):: var
@@ -405,9 +436,9 @@ module an_generic
       integer, intent(in):: stride(:)
       integer, intent(in):: imap(:)
       integer, intent(in):: siz
-      double precision, intent(in):: value(siz)
+      integer, intent(in):: value(siz)
       integer, intent(out):: iostat
-    end subroutine anvarputdouble
+    end subroutine ANVarPutInt
 
   end interface
 
