@@ -1,8 +1,8 @@
 != netCDF ѿΥץ
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: anvaropen.f90,v 1.2 2006/12/30 08:21:22 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070729 $
+! Version::   $Id: anvaropen.f90,v 1.3 2007/08/24 07:22:02 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070824 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2006. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -33,7 +33,7 @@ continue
   call BeginSub(subname)
   call UrlSplit(url, file=filename, var=varname)
   if (filename == "") filename = "gtool.nc"
-  call ANFileOpen(e%fileid, trim(filename), stat=stat, writable=writable)
+  call ANFileOpen(e%fileid, trim(filename), stat=stat, writable=writable, err=err )
   if (stat /= 0) goto 999
   !
   ! ̾ѿõФ
