@@ -1,8 +1,8 @@
 !== Monitor of CPU TIME
 !
 ! Authors::   Yasuhiro MORIKAWA
-! Version::   $Id: dc_clock.f90,v 1.15 2007/06/16 06:20:25 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070729 $
+! Version::   $Id: dc_clock.f90,v 1.16 2007/08/22 15:47:07 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070824 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2006. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -159,8 +159,8 @@ module dc_clock
 
 
   character(*), parameter:: version = &
-    & '$Name: gt4f90io-20070729 $' // &
-    & '$Id: dc_clock.f90,v 1.15 2007/06/16 06:20:25 morikawa Exp $'
+    & '$Name: gt4f90io-20070824 $' // &
+    & '$Id: dc_clock.f90,v 1.16 2007/08/22 15:47:07 morikawa Exp $'
 
 contains
 
@@ -522,7 +522,7 @@ contains
     ! 顼ȯޤ. *err* Ϳˤ *err*  .true. ֤,
     ! ץ³Ԥޤ.
     !
-    use dc_types, only: STDOUT, STRING
+    use dc_types, only: STDOUT, STRING, DP
     use dc_message, only: MessageNotify
     use dc_string, only: Printf, toChar, CPrintf
     use dc_date, only: EvalSec
@@ -540,6 +540,7 @@ contains
     character(STRING):: total_name_work
     type(CLOCK):: clk_auto_total
     logical:: total_print_complete
+    real(DP):: elapsed_time_val_cor
     integer:: stat
     character(*), parameter:: total_time_mes = '       TOTAL TIME = '
     character(*), parameter:: subname = 'DCClockResult'
@@ -572,9 +573,11 @@ contains
       & c1=trim(total_name_work) // ' ')
     do i = 1, clks_size
       clk_name = clks(i) % name
+      elapsed_time_val_cor = EvalSec(clks(i) % elapsed_time)
+      if (elapsed_time_val_cor < 0.0_DP) elapsed_time_val_cor = 0.0_DP
       call Printf(out_unit, &
         & ' %c%c  %c', c1=clk_name, &
-        & c2=trim(result_value_form(EvalSec(clks(i) % elapsed_time))), &
+        & c2=trim(result_value_form(elapsed_time_val_cor)), &
         & c3=trim(fit_unit_value(clks(i) % elapsed_time)))
     end do
     total_print_complete = .false.
@@ -582,9 +585,11 @@ contains
       if (clk_total % initialized) then
         call Printf(out_unit, &
           & ' ------------------------------------------------')
+        elapsed_time_val_cor = EvalSec(clk_total % elapsed_time)
+        if (elapsed_time_val_cor < 0.0_DP) elapsed_time_val_cor = 0.0_DP
         call Printf(out_unit, &
           & ' %c%c  %c', c1=total_time_mes, &
-          & c2=trim(result_value_form(EvalSec(clk_total % elapsed_time))), &
+          & c2=trim(result_value_form(elapsed_time_val_cor)), &
           & c3=trim(fit_unit_value(clk_total % elapsed_time)))
         total_print_complete = .true.
       end if
@@ -600,9 +605,11 @@ contains
         end if
         call Printf(out_unit, &
           & ' ------------------------------------------------')
+        elapsed_time_val_cor = EvalSec(clk_auto_total % elapsed_time)
+        if (elapsed_time_val_cor < 0.0_DP) elapsed_time_val_cor = 0.0_DP
         call Printf(out_unit, &
           & ' %c%c  %c', c1=total_time_mes, &
-          & c2=trim(result_value_form(EvalSec(clk_auto_total % elapsed_time))), &
+          & c2=trim(result_value_form(elapsed_time_val_cor)), &
           & c3=trim(fit_unit_value(clk_auto_total % elapsed_time)))
       end if
     end if
