@@ -3,8 +3,8 @@
 != Error handling
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dc_error.f90,v 1.19 2007/07/21 13:14:10 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070729 $
+! Version::   $Id: dc_error.f90,v 1.20 2007/08/24 07:22:43 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070824 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -295,6 +295,9 @@ module dc_error
   !
   ! -118    :: [ <b>GT_ERANKMISMATCH</b> ]
   !            <b></b> :: rank of data and argument is mismatch (<i>cause_c</i>)
+  ! -119    :: [ <b>GT_ENOTURL     </b> ] 
+  !            <b></b> :: URL (<i>cause_c</i>) is not found
+  !
   !
   ! -299  :: <b>                     </b>
   !            <b></b> :: ( gtdata ؤγĥΤͽ.
@@ -442,6 +445,7 @@ module dc_error
   integer, parameter, public:: GT_EBADHISTORY      = -116
   integer, parameter, public:: GT_EBADALLOCATESIZE = -117
   integer, parameter, public:: GT_ERANKMISMATCH    = -118
+  integer, parameter, public:: GT_ENOTURL          = -119
 
   !
   ! -300 ʲ: GrADS ϤΥ顼
@@ -546,6 +550,8 @@ contains
       msg = " invalid allocated size"
     case(GT_ERANKMISMATCH)
       msg = " rank of data and argument are mismatch (" // trim(cause_string) // ")"
+    case(GT_ENOTURL)
+      msg = " URL (" // trim(cause_string) // ") is not found"
       !
       ! -300 ʲ: GrADS ϤΥ顼
       ! -300 or less: Error of GrADS I/O
