@@ -1,8 +1,8 @@
 !== Sample program for gt4_history/gt4f90io
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: histget.f90,v 1.13 2006/09/09 08:26:57 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070729 $
+! Version::   $Id: histget.f90,v 1.15 2007/08/24 09:51:59 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070824 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../COPYRIGHT]
 !
@@ -16,6 +16,7 @@ program histget
   use dc_message, only: MessageNotify
   use dc_types,   only: STRING, DP
   use dc_string,  only: StoA, toChar
+  use dc_test, only: AssertEqual
   use gt4_history
   implicit none
   integer             :: i,j,k,l                        ! ѿ
@@ -28,12 +29,12 @@ program histget
   real                :: u           ! ̵
   real(DP)            :: v(nx)       !  1 
   real(DP)            :: v2(nz)      !  1 󤽤2
-  real                :: w(nx,ny)    !  2 
+  integer             :: w(nx,ny)    !  2 
   real(DP)            :: q(nx,ny,nz) !  3 
 
   real,     pointer   :: up       =>null() ! ̵ݥ
   real(DP), pointer   :: vp(:)    =>null() !  1 ݥ
-  real,     pointer   :: wp(:,:)  =>null() !  2 ݥ
+  integer,  pointer   :: wp(:,:)  =>null() !  2 ݥ
   real(DP), pointer   :: qp(:,:,:)=>null() !  3 ݥ
 
   real,     pointer   :: xp(:) =>null()    !  xɸݥ
@@ -43,11 +44,19 @@ program histget
   real(DP), pointer   :: vp_range     =>null() ! range Ǥϥƥ
   real(DP), pointer   :: qp_range(:,:)=>null() ! range Ǥϥƥ
 
+  logical:: err
   character(string), parameter  :: subname = 'histget'
 continue
 
   call SetDebug
 
+  !-----------------------------------------------------------------
+  ! 顼ե饰Υå
+  !-----------------------------------------------------------------
+  err = .false.
+  call HistoryGet('xhistget/xhistget_non.nc', 'v', v, err = err)
+  call AssertEqual('err flag test 1', answer = .true., check = err)
+
   !-----------------------------------------------------------------
   ! ޤѤΥե
   !-----------------------------------------------------------------
@@ -78,7 +87,7 @@ continue
     & units='1-dimensional any unit', xtype='double')
   call HistoryAddVariable('w', dims=(/'x','y','t'/), &
     & longname='2 Dimensional any quantity', &
-    & units='2-dimensional any unit')
+    & units='2-dimensional any unit', xtype='int')
   call HistoryAddVariable('q', dims=(/'x','y','z','t'/), &
     & longname='3 Dimensional any quantity', &
     & units='3-dimensional any unit', xtype='double')
@@ -88,8 +97,7 @@ continue
     do i = 1, nx
       v(i) = dble(l)*0.100000001d0+dble(i)*10.0000001d0
       do j = 1, ny
-        w(i,j) = real(l)*0.100000001 + real(i)*10.0000001 &
-          & + real(j)*1000.00001
+        w(i,j) = l + i * 10 + j * 1000
         do k = 1, nz
           q(i,j,k) = dble(l)*0.100000001d0     &
             & + dble(i)*10.0000001d0  &
@@ -151,7 +159,7 @@ continue
     & units='1-dimensional any unit', xtype='double')
   call HistoryAddVariable('w', dims=(/'x','y','t'/), &
     & longname='2 Dimensional any quantity', &
-    & units='2-dimensional any unit')
+    & units='2-dimensional any unit', xtype='int')
   call HistoryAddVariable('q', dims=(/'x','y','z','t'/), &
     & longname='3 Dimensional any quantity', &
     & units='3-dimensional any unit', xtype='double')
@@ -159,9 +167,9 @@ continue
   do, l = 1, time_period - 1
     call HistoryPut('t', real(l)*0.2)
     call HistoryGet(file='xhistget/xhistget1.nc', varname='u', & 
-      &          array=u, time=real(l)*0.2)
+      &          array=u, range=toChar(real(l)*0.2))
     call HistoryPut('u', u)
-    call HistoryGet('xhistget/xhistget1.nc', 'v', v, dble(l)*0.2d0)
+    call HistoryGet('xhistget/xhistget1.nc', 'v', v, toChar(dble(l)*0.2d0))
     call HistoryPut('v', v)
     call HistoryGet('xhistget/xhistget1.nc', 'v2', v2, range='t=^'//toChar(l))
     call HistoryPut('v2', v2)
@@ -220,7 +228,7 @@ continue
     & units='1-dimensional any unit', xtype='double')
   call HistoryAddVariable('w', dims=(/'x','y','t'/), &
     & longname='2 Dimensional any quantity', &
-    & units='2-dimensional any unit')
+    & units='2-dimensional any unit', xtype='int')
   call HistoryAddVariable('q', dims=(/'x','y','z','t'/), &
     & longname='3 Dimensional any quantity', &
     & units='3-dimensional any unit', xtype='double')
@@ -228,10 +236,10 @@ continue
   do, l = 1, time_period - 1
     call HistoryPut('t', real(l)*0.2)
     call HistoryGetPointer(file='xhistget/xhistget1.nc', varname='u', & 
-      &          array=up, time=real(l)*0.2)
+      &          array=up, range=toChar(real(l)*0.2))
     call HistoryPut('u', up)
     if (associated(vp)) deallocate(vp)
-    call HistoryGetPointer('xhistget/xhistget1.nc', 'v', vp, dble(l)*0.2d0)
+    call HistoryGetPointer('xhistget/xhistget1.nc', 'v', vp, toChar(dble(l)*0.2d0))
     call HistoryPut('v', vp)
     if (associated(vp)) deallocate(vp)
     call HistoryGetPointer('xhistget/xhistget1.nc', 'v2', vp, range='^'//toChar(l))
@@ -251,7 +259,7 @@ continue
   call HistoryGetPointer('xhistget/xhistget1.nc', 'v', vp)
   call HistoryPut('v', vp)
   if (associated(vp)) deallocate(vp)
-  call HistoryGetPointer('xhistget/xhistget1.nc', 'v2', vp, dble(l)*0.2d0)
+  call HistoryGetPointer('xhistget/xhistget1.nc', 'v2', vp, toChar(dble(l)*0.2d0))
   call HistoryPut('v2', vp)
   call HistoryGetPointer('xhistget/xhistget1.nc', 'w', wp)
   call HistoryPut('w', wp)
@@ -297,7 +305,7 @@ continue
     & units='1-dimensional any unit', xtype='double')
   call HistoryAddVariable('w', dims=(/'x','y','t'/), &
     & longname='2 Dimensional any quantity', &
-    & units='2-dimensional any unit')
+    & units='2-dimensional any unit', xtype='int')
   call HistoryAddVariable('q', dims=(/'x','y','z','t'/), &
     & longname='3 Dimensional any quantity', &
     & units='3-dimensional any unit', xtype='double')
@@ -305,10 +313,10 @@ continue
   do, l = 1, time_period
     call HistoryPut('t', real(l)*0.2)
     call HistoryGetPointer(file='xhistget/xhistget1.nc', varname='u', & 
-      &          array=up, time=real(l)*0.2)
+      &          array=up, range=toChar(real(l)*0.2))
     call HistoryPut('u', up)
     if (associated(vp)) deallocate(vp)
-    call HistoryGetPointer('xhistget/xhistget1.nc', 'v', vp, dble(l)*0.2d0)
+    call HistoryGetPointer('xhistget/xhistget1.nc', 'v', vp, toChar(dble(l)*0.2d0))
     call HistoryPut('v', vp)
     if (associated(vp)) deallocate(vp)
     call HistoryGetPointer('xhistget/xhistget1.nc', 'v2', vp, range='^'//toChar(l))
@@ -355,7 +363,7 @@ continue
     & units='1-dimensional any unit', xtype='double')
   call HistoryAddVariable('w', dims=(/'x','y','t'/), &
     & longname='2 Dimensional any quantity', &
-    & units='2-dimensional any unit')
+    & units='2-dimensional any unit', xtype='int')
   call HistoryAddVariable('q', dims=(/'x','y','z','t'/), &
     & longname='3 Dimensional any quantity', &
     & units='3-dimensional any unit', xtype='double')
@@ -363,7 +371,7 @@ continue
   do, l = 1, time_period - 1
     call HistoryPut('t', real(l)*0.2)
     call HistoryGet(file='xhistget/xhistget1.nc', varname='u', & 
-      &          array=u, time=real(l)*0.2 + 0.05)
+      &          array=u, range=toChar(real(l)*0.2 + 0.05))
     call HistoryPut('u', u)
 
     do i = 1, size(xp)
