@@ -1,8 +1,8 @@
 !== Sample program for gt4_history/gt4f90io
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: histtest.f90,v 1.8 2006/06/16 04:58:47 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070729 $
+! Version::   $Id: histtest.f90,v 1.9 2007/08/22 18:34:28 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070824 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../COPYRIGHT]
 !
@@ -102,16 +102,16 @@ continue
   call HistoryAddVariable('u', dims=(/'x   ', 'time'/), &
     & longname='foo quantity', units='m/s')
   call HistoryAddVariable('v', dims=(/'x   ', 'time'/), &
-    & longname='foo quantity', units='m/s')
+    & longname='foo quantity', units='m/s', xtype='int')
   call HistoryPut('x', (/0.0, 1.0, 2.0/))
   call HistoryPut('time', 0.0)
   call HistoryPut('u', (/0.0, 0.1, 0.2/))
-  call HistoryPut('v', (/1.0, 1.1, 1.2/))
+  call HistoryPut('v', (/10, 11, 12/))
   call HistoryPut('time', 1.0)
   call HistoryPut('u', (/2.0, 2.1, 2.2/))
   call HistoryPut('time', 2.0)
   call HistoryPut('u', (/3.0, 3.1, 3.2/))
-  call HistoryPut('v', (/4.0, 4.1, 4.2/))
+  call HistoryPut('v', (/40, 41, 42/))
   call HistoryClose
 
   !-----------------------------------------------------------------
